@@ -25,3 +25,7 @@ packageStartupMessage(paste(
 
 }
 
+# mode argument below not really necessary:
+if(!exists("DWEnv",mode="environment")){
+    DWEnv<-new.env()
+} 
